@@ -72,7 +72,7 @@ class CellMethod(cfdm.CellMethod):
 
     **Examples:**
 
-    TODO
+    c = CellMethod.create('lat: mean (interval: 1 hour)')
 
         '''
         incorrect_interval = 'Cell method interval is incorrectly formatted'
@@ -373,7 +373,7 @@ class CellMethod(cfdm.CellMethod):
     <CF CellMethod: time: minimum (interval: 1 hr)>
     >>> c.intervals
     (<CF Data: 1 hr>,)
-    >>> c.intervals = [cf.Data(7.5 'minutes')]
+    >>> c.intervals = [cf.Data(7.5, 'minutes')]
     >>> c
     <CF CellMethod: time: minimum (interval: 7.5 minutes)>
     >>> c.intervals
@@ -389,7 +389,7 @@ class CellMethod(cfdm.CellMethod):
     <CF CellMethod: lat: lon: mean (interval: 0.1 degree_N interval: 0.2 degree_E)>
 
         '''
-        self.get_qualifier('interval', default=AttributeError())
+        return self.get_qualifier('interval', default=AttributeError())
 
     @intervals.setter
     def intervals(self, value):
@@ -534,7 +534,7 @@ class CellMethod(cfdm.CellMethod):
         axes = self.get_axes(None)
         if axes is not None:
             out.append("{}.set_axes({!r})".format(name, axes))
-            
+
         for term, value in self.qualifiers().items():
             if term == 'interval':
                 value = deepcopy(value)
@@ -546,7 +546,7 @@ class CellMethod(cfdm.CellMethod):
                     else:
                         value[i] = str(data)
                 # --- End: for
-                
+
                 value = ', '.join(value)
                 value = "["+value+"]"
             else:
