@@ -899,7 +899,8 @@ class DimensionCoordinate(mixin.Coordinate,
         c.dtype = numpy_result_type(c.dtype, period.dtype)
 
         b = c.get_bounds(None)
-        bounds_data = b.get_data(None)
+        bounds_data = c.get_bounds_data(None)
+
         if bounds_data is not None:
             b.dtype = numpy_result_type(bounds_data.dtype, period.dtype)
             bounds_data = b.get_data(None)
