@@ -7,6 +7,8 @@ from copy import deepcopy
 from .functions import RTOL, ATOL, equals
 from .functions import inspect as cf_inspect
 
+from .decorators import _deprecated_kwarg_check
+
 
 class Flags:
     '''Self-describing CF flag values.
@@ -17,17 +19,17 @@ class Flags:
     '''
     def __init__(self, **kwargs):
         '''**Initialization**
-    
+
     :Parameters:
-    
+
         flag_values : optional
             The flag_values CF property. Sets the `flag_values`
             attribute.
-    
+
         flag_meanings : optional
             The flag_meanings CF property. Sets the `flag_meanings`
             attribute.
-    
+
         flag_masks : optional
             The flag_masks CF property. Sets the `flag_masks`
             attribute.
@@ -37,21 +39,18 @@ class Flags:
             if value is not None:
                 setattr(self, attr, value)
 
-
     def __eq__(self, other):
         '''x.__eq__(y) <==> x==y <==> x.equals(y)
-        
+
         '''
         return self.equals(other)
 
-
     def __ne__(self, other):
         '''x.__ne__(y) <==> x!=y <==> not x.equals(y)
-        
+
         '''
         return not self.equals(other)
 
-
     def __hash__(self):
         '''Return the hash value of the flags.
 
@@ -70,12 +69,11 @@ class Flags:
         '''
         self.sort()
 
-        x = [tuple(getattr(self, attr, ())) 
+        x = [tuple(getattr(self, attr, ()))
              for attr in ('_flag_meanings', '_flag_values', '_flag_masks')]
 
         return hash(tuple(x))
 
-
     def __bool__(self):
         '''x.__bool__() <==> x!=0
 
@@ -83,11 +81,10 @@ class Flags:
         for attr in ('_flag_meanings', '_flag_values', '_flag_masks'):
             if hasattr(self, attr):
                 return True
-        #--- End: for
+        # --- End: for
 
         return False
 
-
     # ----------------------------------------------------------------
     # Attributes
     # ----------------------------------------------------------------
@@ -97,9 +94,9 @@ class Flags:
 
     Stored as a 1-d numpy array but may be set as any array-like
     object.
-    
-    **Examples:*
-    
+
+    **Examples:**
+
     >>> f.flag_values = ['a', 'b', 'c']
     >>> f.flag_values
     array(['a', 'b', 'c'], dtype='|S1')
@@ -131,18 +128,17 @@ class Flags:
             raise AttributeError("Can't delete '%s' attribute 'flag_values'" %
                                  self.__class__.__name__)
 
-
     # ----------------------------------------------------------------
     # Property attribute: flag_masks
     # ----------------------------------------------------------------
     @property
     def flag_masks(self):
         '''The flag_masks CF attribute.
-    
+
     Stored as a 1-d numpy array but may be set as array-like object.
-    
-    **Examples:*
-    
+
+    **Examples:**
+
     >>> f.flag_masks = numpy.array([1, 2, 4], dtype='int8')
     >>> f.flag_masks
     array([1, 2, 4], dtype=int8)
@@ -172,16 +168,15 @@ class Flags:
             raise AttributeError("Can't delete '%s' attribute 'flag_masks'" %
                                  self.__class__.__name__)
 
-
     @property
     def flag_meanings(self):
         '''The flag_meanings CF attribute.
 
     Stored as a 1-d numpy string array but may be set as a space
     delimited string or any array-like object.
-    
-    **Examples:*
-    
+
+    **Examples:**
+
     >>> f.flag_meanings = 'low medium      high'
     >>> f.flag_meanings
     array(['low', 'medium', 'high'],
@@ -203,8 +198,10 @@ class Flags:
         try:
             return self._flag_meanings
         except AttributeError:
-            raise AttributeError("'%s' object has no attribute 'flag_meanings'" %
-                                 self.__class__.__name__)
+            raise AttributeError(
+                "'%s' object has no attribute 'flag_meanings'" %
+                self.__class__.__name__
+            )
 
     @flag_meanings.setter
     def flag_meanings(self, value):
@@ -220,9 +217,10 @@ class Flags:
         try:
             del self._flag_meanings
         except AttributeError:
-            raise AttributeError("Can't delete '%s' attribute 'flag_meanings'" %
-                                 self.__class__.__name__)
-
+            raise AttributeError(
+                "Can't delete '%s' attribute 'flag_meanings'" %
+                self.__class__.__name__
+            )
 
     def __repr__(self):
         '''x.__repr__() <==> repr(x)
@@ -241,36 +239,34 @@ class Flags:
         return '<CF %s: %s>' % (self.__class__.__name__,
                                 ', '.join(string))
 
-
     def copy(self):
         '''Return a deep copy.
 
     Equivalent to ``copy.deepcopy(f)``
-    
+
     :Returns:
-    
+
             The deep copy.
-    
-    **Examples:*
-    
+
+    **Examples:**
+
     >>> f.copy()
 
         '''
         return deepcopy(self)
 
-
     def dump(self, display=True, _level=0):
         '''Return a string containing a full description of the instance.
 
     :Parameters:
-     
+
         display : bool, optional
             If False then return the description as a string. By
             default the description is printed, i.e. ``f.dump()`` is
             equivalent to ``print(f.dump(display=False))``.
-    
+
     :Returns:
-    
+
         `None` or `str`
             A string containing the description.
 
@@ -284,55 +280,55 @@ class Flags:
             value = getattr(self, attr, None)
             if value is not None:
                 string.append('%s%s = %s' % (indent1, attr[1:], list(value)))
-        #--- End: for
-                
+        # --- End: for
+
         string = '\n'.join(string)
-        
+
         if display:
             print(string)
         else:
             return(string)
 
-
+    @_deprecated_kwarg_check('traceback')
     def equals(self, other, rtol=None, atol=None,
                ignore_fill_value=False, verbose=False,
                traceback=False):
         '''True if two groups of flags are logically equal, False otherwise.
 
     Note that both instances are sorted in place prior to the comparison.
-    
+
     :Parameters:
-    
-        other: 
+
+        other:
             The object to compare for equality.
-    
+
         atol: float, optional
             The absolute tolerance for all numerical comparisons, By
             default the value returned by the `ATOL` function is used.
-    
+
         rtol: float, optional
             The relative tolerance for all numerical comparisons, By
             default the value returned by the `RTOL` function is used.
-    
+
         ignore_fill_value: bool, optional
             If True then data arrays with different fill values are
             considered equal. By default they are considered unequal.
-    
+
         traceback: deprecated at version 3.0.0.
             Use *verbose* instead.
-    
+
     :Returns:
-    
+
         `bool`
             Whether or not the two instances are equal.
-     
-    **Examples:*
-    
+
+    **Examples:**
+
     >>> f
     <CF Flags: flag_values=[1 0 2], flag_masks=[2 0 2], flag_meanings=['medium' 'low' 'high']>
     >>> g
     <CF Flags: flag_values=[2 0 1], flag_masks=[2 0 2], flag_meanings=['high' 'low' 'medium']>
-    >>> f.equals(g) 
+    >>> f.equals(g)
     True
     >>> f
     <CF Flags: flag_values=[0 1 2], flag_masks=[0 2 2], flag_meanings=['low' 'medium' 'high']>
@@ -340,15 +336,15 @@ class Flags:
     <CF Flags: flag_values=[0 1 2], flag_masks=[0 2 2], flag_meanings=['low' 'medium' 'high']>
 
         '''
-        if traceback:
-            _DEPRECATION_ERROR_KWARGS(self, 'equals', traceback=True) # pragma: no cover
-      
         # Check that each instance is the same type
         if self.__class__ != other.__class__:
             if verbose:
-                print("%s: Different type: %s, %s" %
-                      (self.__class__.__name__,
-                       self.__class__.__name__, other.__class__.__name__)) # pragma: no cover
+                print(
+                    "%s: Different type: %s, %s" % (
+                        self.__class__.__name__,
+                        self.__class__.__name__, other.__class__.__name__
+                    )
+                )  # pragma: no cover
             return False
 
         self.sort()
@@ -358,64 +354,68 @@ class Flags:
         if rtol is None:
             rtol = RTOL()
         if atol is None:
-            atol = ATOL()        
+            atol = ATOL()
 
         for attr in ('_flag_meanings', '_flag_values', '_flag_masks'):
             if hasattr(self, attr):
                 if not hasattr(other, attr):
                     if verbose:
-                        print("%s: Different attributes: %s" %
-                              (self.__class__.__name__, attr[1:])) # pragma: no cover
+                        print(
+                            "%s: Different attributes: %s" %
+                            (self.__class__.__name__, attr[1:])
+                        )  # pragma: no cover
                     return False
 
                 x = getattr(self, attr)
                 y = getattr(other, attr)
 
-                if (x.shape != y.shape or 
+                if (x.shape != y.shape or
                     not equals(x, y, rtol=rtol, atol=atol,
                                ignore_fill_value=ignore_fill_value,
                                verbose=verbose)):
                     if verbose:
-                        print("%s: Different '%s': %r, %r" %
-                              (self.__class__.__name__, attr[1:], x, y)) # pragma: no cover
+                        print(
+                            "%s: Different '%s': %r, %r" %
+                            (self.__class__.__name__, attr[1:], x, y)
+                        )  # pragma: no cover
                     return False
 
-            elif hasattr(other, attr): 
+            elif hasattr(other, attr):
                 if verbose:
-                    print("%s: Different attributes: %s" %
-                          (self.__class__.__name__, attr[1:])) # pragma: no cover
+                    print(
+                        "%s: Different attributes: %s" %
+                        (self.__class__.__name__, attr[1:])
+                    )  # pragma: no cover
                 return False
-        #--- End: for
+        # --- End: for
 
         return True
 
-
     def inspect(self):
         '''Inspect the object for debugging.
-    
+
     .. seealso:: `cf.inspect`
-    
-    :Returns: 
-    
+
+    :Returns:
+
         `None`
 
         '''
-        print(cf_inspect(self)) # pragma: no cover
-
+        print(cf_inspect(self))  # pragma: no cover
 
     def sort(self):
         '''Sort the flags in place.
-    
+
     By default sort by flag values. If flag values are not present
     then sort by flag meanings. If flag meanings are not present then
     sort by flag_masks.
-    
+
     :Returns:
-    
+
         `None`
-    
-    **Examples:*
-    
+
+    **Examples:**
+
     >>> f
     <CF Flags: flag_values=[2 0 1], flag_masks=[2 0 2], flag_meanings=['high' 'low' 'medium']>
     >>> f.sort()
@@ -431,13 +431,13 @@ class Flags:
             if hasattr(self, attr):
                 indices = numpy_argsort(getattr(self, attr))
                 break
-        #--- End: for
+        # --- End: for
 
         for attr in ('_flag_values', '_flag_meanings', '_flag_masks'):
             if hasattr(self, attr):
-                array      = getattr(self, attr).view()
+                array = getattr(self, attr).view()
                 array[...] = array[indices]
-        #--- End: for
+        # --- End: for
 
 
-#--- End: class
+# --- End: class
