@@ -36,14 +36,14 @@ class FieldTest(unittest.TestCase):
 
         f = f + f.copy()
         self.assertTrue(len(f) == 2)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         f += (f[0].copy(),)
         self.assertTrue(len(f) == 3)
 
         f += [f[0].copy()]
         self.assertTrue(len(f) == 4)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         f += list(f[0].copy())
         self.assertTrue(len(f) == 5)
@@ -74,13 +74,15 @@ class FieldTest(unittest.TestCase):
         f = cf.read(self.filename)
         self.assertTrue(f.close() is None)
 
+        _ = repr(f[0])
+
 
     def test_FieldList__len__(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
         f = cf.read(self.filename)
-        
+
         self.assertTrue(len(cf.FieldList()) == 0)
         self.assertTrue(len(f) == 1)
         f.append(f[0].copy())
@@ -96,30 +98,30 @@ class FieldTest(unittest.TestCase):
         f = cf.FieldList()
         f = f * 4
         self.assertTrue(len(f) == 0)
-        self.assertTrue(isinstance(f, cf.FieldList))
-        
+        self.assertIsInstance(f, cf.FieldList)
+
         f = cf.FieldList()
         f *= 4
         self.assertTrue(len(f) == 0)
-        self.assertTrue(isinstance(f, cf.FieldList))
-        
+        self.assertIsInstance(f, cf.FieldList)
+
         f = cf.read(self.filename)
         f = f * 4
         self.assertTrue(len(f) == 4)
-        self.assertTrue(isinstance(f, cf.FieldList))
-        
+        self.assertIsInstance(f, cf.FieldList)
+
         f = cf.read(self.filename)
         f *= 4
         self.assertTrue(len(f) == 4)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         f = f * 2
         self.assertTrue(len(f) == 8)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         f *= 3
         self.assertTrue(len(f) == 24)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
 
     def test_FieldList__repr__(self):
@@ -141,12 +143,12 @@ class FieldTest(unittest.TestCase):
 
         f.append(cf.read(self.filename)[0])
         self.assertTrue(len(f) == 1)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         f.append(f[0].copy())
         self.assertTrue(len(f) == 2)
-        self.assertTrue(isinstance(f, cf.FieldList))
-                
+        self.assertIsInstance(f, cf.FieldList)
+
         f.append(f[0].copy())
         self.assertTrue(len(f) == 3)
 
@@ -155,12 +157,12 @@ class FieldTest(unittest.TestCase):
 
         f.extend(cf.read(self.filename))
         self.assertTrue(len(f) == 1)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         f.extend(f.copy())
         self.assertTrue(len(f) == 2)
-        self.assertTrue(isinstance(f, cf.FieldList))
-                
+        self.assertIsInstance(f, cf.FieldList)
+
         f.extend(f.copy())
         self.assertTrue(len(f) == 4)
 
@@ -186,7 +188,7 @@ class FieldTest(unittest.TestCase):
         _ = f[0:1]
         _ = f[1:2]
         _ = f[:1]
-        _ = f[1:]        
+        _ = f[1:]
 
 
     def test_FieldList_count(self):
@@ -201,7 +203,7 @@ class FieldTest(unittest.TestCase):
         self.assertTrue(f.count(f[0]) == 7)
 
         f[3] = f[0] * 99
-        f[5] = f[0] * 99 
+        f[5] = f[0] * 99
         self.assertTrue(f.count(f[0]) == 5)
         self.assertTrue(f.count(f[3]) == 2)
 
@@ -214,7 +216,7 @@ class FieldTest(unittest.TestCase):
         g = f.copy()
         self.assertTrue(f.equals(f, verbose=True))
         self.assertTrue(f.equals(g, verbose=True))
-        
+
         f += g.copy()
         self.assertTrue(f.equals(f, verbose=True))
         self.assertTrue(len(f) == 2)
@@ -226,7 +228,7 @@ class FieldTest(unittest.TestCase):
         f.extend(h)
         self.assertTrue(f.equals(f, verbose=True))
         self.assertTrue(f.equals(f.copy(), verbose=True))
-        
+
         g = f.copy()[::-1]
         self.assertFalse(f.equals(g))
         self.assertTrue(f.equals(g, unordered=True, verbose=True))
@@ -241,7 +243,7 @@ class FieldTest(unittest.TestCase):
 
         h *= 3
         self.assertFalse(f.equals(h))
-        self.assertFalse(f.equals(h, unordered=True))       
+        self.assertFalse(f.equals(h, unordered=True))
 
 
     def test_FieldList_insert_pop_remove(self):
@@ -251,15 +253,15 @@ class FieldTest(unittest.TestCase):
         # Insert
         f = cf.read(self.filename)
         g = f[0].copy()
-                
+
         f.insert(0, g.copy())
         self.assertTrue(len(f) == 2)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         g = g + 10
         f.insert(-1, g)
         self.assertTrue(len(f) == 3)
-        self.assertTrue(f[0].max() == (f[1].max() - 10))
+        self.assertTrue(f[0].maximum() == (f[1].maximum() - 10))
         self.assertTrue(isinstance(f, cf.FieldList))
 
         # Pop
@@ -271,32 +273,32 @@ class FieldTest(unittest.TestCase):
         z = f.pop(0)
         self.assertTrue(z is g)
         self.assertTrue(len(f) == 1)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         z = f.pop(-1)
         self.assertTrue(z is h)
         self.assertTrue(len(f) == 0)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         # Remove
         f = cf.read(self.filename)
         g = f[0].copy()
         g = g + 10
-                
+
         f.append(g)
         self.assertTrue(len(f) == 2)
-        
+
         f.remove(g)
         self.assertTrue(len(f) == 1)
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
 
         with self.assertRaises(Exception):
             f.remove(f[0]*-99)
-            
+
         f.remove(f[0].copy())
         self.assertTrue(len(f) == 0)
-        self.assertTrue(isinstance(f, cf.FieldList))
-            
+        self.assertIsInstance(f, cf.FieldList)
+
 
     def test_FieldList_reverse(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -311,7 +313,7 @@ class FieldTest(unittest.TestCase):
         self.assertTrue(h is f[1])
 
         f.reverse()
-        self.assertTrue(isinstance(f, cf.FieldList))
+        self.assertIsInstance(f, cf.FieldList)
         self.assertTrue(len(f) == 2)
         self.assertTrue(g is f[1])
         self.assertTrue(h is f[0])
@@ -324,15 +326,15 @@ class FieldTest(unittest.TestCase):
         f = cf.read(self.filename)
 
         g = f('not this one')
-        self.assertTrue(isinstance(g, cf.FieldList), type(g))
+        self.assertIsInstance(g, cf.FieldList)
         self.assertTrue(len(g) == 0)
 
         g = f('eastward_wind')
-        self.assertTrue(isinstance(g, cf.FieldList))
+        self.assertIsInstance(g, cf.FieldList)
         self.assertTrue(len(g) == 1, len(g))
 
         g = f(re.compile('^eastw'))
-        self.assertTrue(isinstance(g, cf.FieldList))
+        self.assertIsInstance(g, cf.FieldList)
         self.assertTrue(len(g) == 1, len(g))
 
         f *= 9
@@ -342,11 +344,11 @@ class FieldTest(unittest.TestCase):
         f[6].standard_name = 'this one'
 
         g = f(re.compile('^eastw'))
-        self.assertTrue(isinstance(g, cf.FieldList))
+        self.assertIsInstance(g, cf.FieldList)
         self.assertTrue(len(g) == 7, len(g))
 
         g = f('this one')
-        self.assertTrue(isinstance(g, cf.FieldList))
+        self.assertIsInstance(g, cf.FieldList)
         self.assertTrue(len(g) == 2)
 
         # select_by_Units
@@ -373,7 +375,7 @@ class FieldTest(unittest.TestCase):
 
         self.assertTrue(len(f.select_by_units('long_name=qwery:asd')) == 0)
 
-        
+
     def test_FieldList_select_by_construct(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -382,19 +384,19 @@ class FieldTest(unittest.TestCase):
 
         g = f.select_by_construct()
         self.assertTrue(len(g) == 2)
-        
+
         g = f.select_by_construct('latitude')
         self.assertTrue(len(g) == 2)
-        
+
         g = f.select_by_construct('latitude', 'longitude')
         self.assertTrue(len(g) == 2)
-        
+
         g = f.select_by_construct('latitude', 'time')
         self.assertTrue(len(g) == 1)
-        
+
         g = f.select_by_construct('latitude', 'time', OR=False)
         self.assertTrue(len(g) == 1)
-        
+
         g = f.select_by_construct('latitude', 'time', OR=True)
         self.assertTrue(len(g) == 2)
 
@@ -424,13 +426,13 @@ class FieldTest(unittest.TestCase):
 
         g = f.select_by_construct('qwerty')
         self.assertTrue(len(g) == 0)
-        
+
         g = f.select_by_construct('qwerty', 'latitude')
         self.assertTrue(len(g) == 0)
-        
+
         g = f.select_by_construct('qwerty', 'latitude', OR=True)
         self.assertTrue(len(g) == 2)
-        
+
         g = f.select_by_construct('qwerty', 'time', 'longitude')
         self.assertTrue(len(g) == 0)
 
@@ -443,27 +445,26 @@ class FieldTest(unittest.TestCase):
         g = f.select_by_construct(longitude=cf.gt(0), time=cf.le(cf.dt('1999-12-01')))
         self.assertTrue(len(g) == 0)
 
-        
+
     def test_FieldList_select_field(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
         f = cf.read(self.filename)
 
-        with self.assertRaises(Exception):            
+        with self.assertRaises(Exception):
             _ = f.select_field('not this one')
-            
+
         self.assertTrue(f.select_field('not this one', None) is None)
-        
+
         g = f.select_field('eastward_wind')
-        self.assertTrue(isinstance(g, cf.Field))
+        self.assertIsInstance(g, cf.Field)
 
         g = f.select_field(re.compile('^eastw'))
-        self.assertTrue(isinstance(g, cf.Field))
+        self.assertIsInstance(g, cf.Field)
 
-        with self.assertRaises(Exception):            
+        with self.assertRaises(Exception):
             g = f.select_field(re.compile('^QWERTY'))
-            
 
     def test_FieldList_concatenate(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -472,14 +473,13 @@ class FieldTest(unittest.TestCase):
         f = cf.read(self.filename2)[0]
 
         g = cf.FieldList([f[0], f[1:456], f[456:]])
-        
+
         h = g.concatenate(axis=0)
         self.assertTrue(f.equals(h, verbose=True))
 
         h = g.concatenate(axis=0, _preserve=False)
         self.assertTrue(f.equals(h, verbose=True))
 
-
     def test_FieldList_index(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -510,7 +510,7 @@ class FieldTest(unittest.TestCase):
             _ = g.index(a, start=1)
 
 
-#--- End: class
+# --- End: class
 
 if __name__ == '__main__':
     print('Run date:', datetime.datetime.now())
