@@ -4,17 +4,18 @@ import os
 import unittest
 import atexit
 import inspect
+import shutil
 import subprocess
 
 import numpy
 
 import cf
 
-tmpfile   = tempfile.mktemp('.cf_test')
-tmpfileh  = tempfile.mktemp('.cf_test')
-tmpfilec  = tempfile.mktemp('.cf_test')
-tmpfile0  = tempfile.mktemp('.cf_test')
-tmpfile1  = tempfile.mktemp('.cf_test')
+tmpfile = tempfile.mktemp('.cf_test')
+tmpfileh = tempfile.mktemp('.cf_test')
+tmpfilec = tempfile.mktemp('.cf_test')
+tmpfile0 = tempfile.mktemp('.cf_test')
+tmpfile1 = tempfile.mktemp('.cf_test')
 tmpfiles = [tmpfile, tmpfileh, tmpfilec, tmpfile0, tmpfile1]
 
 def _remove_tmpfiles():
@@ -25,7 +26,8 @@ def _remove_tmpfiles():
             os.remove(f)
         except OSError:
             pass
-
+    # --- End: for
+    
 atexit.register(_remove_tmpfiles)
 
 
@@ -35,7 +37,7 @@ class read_writeTest(unittest.TestCase):
 
     string_filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                    'string_char.nc')
-    
+
 
     chunk_sizes = (17, 34, 300, 100000)[::-1]
     original_chunksize = cf.CHUNKSIZE()
@@ -106,6 +108,8 @@ class read_writeTest(unittest.TestCase):
         f = cf.read(subdir, recursive=True, aggregate=False)
         self.assertTrue(len(f) == 2, f)
 
+        shutil.rmtree(dir)
+        
     def test_read_select(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -188,7 +192,7 @@ class read_writeTest(unittest.TestCase):
                     g = cf.read(tmpfile, verbose=0)
                     self.assertTrue(len(g) == 1, 'g = '+repr(g))
                     g0 = g[0]
-    
+
                     self.assertTrue(f0.equals(g0, verbose=1),
                                     'Bad read/write of format {!r}'.format(fmt))
 
@@ -327,7 +331,7 @@ class read_writeTest(unittest.TestCase):
 
         with self.assertRaises(Exception):
             x = cf.read('test_read_write.py')
-            
+
     def test_read_write_string(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -337,14 +341,14 @@ class read_writeTest(unittest.TestCase):
         n = int(len(f)/2)
 
         for i in range(0, n):
-            
+
             j = i + n
             self.assertTrue(f[i].data.equals(f[j].data, verbose=1),
                             "{!r} {!r}".format(f[i], f[j]))
             self.assertTrue(f[j].data.equals(f[i].data, verbose=1),
                             "{!r} {!r}".format(f[j], f[i]))
-    
-        for string0 in (True, False):        
+
+        for string0 in (True, False):
             for fmt0 in ('NETCDF4',
                          'NETCDF3_CLASSIC',
                          'NETCDF4_CLASSIC',
@@ -354,8 +358,8 @@ class read_writeTest(unittest.TestCase):
 #                print ('fmt0=', fmt0)
                 f0 = cf.read(self.string_filename)
                 cf.write(f0, tmpfile0, fmt=fmt0, string=string0)
-                
-                for string1 in (True, False):        
+
+                for string1 in (True, False):
                     for fmt1 in ('NETCDF4',
                                  'NETCDF3_CLASSIC',
                                  'NETCDF4_CLASSIC',
@@ -365,11 +369,11 @@ class read_writeTest(unittest.TestCase):
 #                        print ('fmt1=', fmt1)
                         f1 = cf.read(self.string_filename)
                         cf.write(f0, tmpfile1, fmt=fmt1, string=string1)
-                        
+
                         for i, j in zip(cf.read(tmpfile1), cf.read(tmpfile0)):
                             self.assertTrue(i.equals(j, verbose=1))
         # --- End: for
-        
+
 # --- End: class
 
 if __name__ == "__main__":
